Documentation
¶
Overview ¶
Package pubkey represents the public key updater fetching logic and the interface
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrFetchAthenzPubkey "Fetch athenz pubkey error" ErrFetchAthenzPubkey = errors.New("Fetch athenz pubkey error") // ErrEmptyAthenzPubkey "Athenz pubkey not initialized" ErrEmptyAthenzPubkey = errors.New("Athenz pubkey not initialized") )
Functions ¶
This section is empty.
Types ¶
type AthenzConfig ¶
type AthenzConfig struct {
ZMSPubKeys *sync.Map //map[string]authcore.Verifier
ZTSPubKeys *sync.Map //map[string]authcore.Verifier
}
AthenzConfig represent the cache of Athenz config.
type Daemon ¶
type Daemon interface {
Start(ctx context.Context) <-chan error
Update(context.Context) error
GetProvider() Provider
}
Daemon represent the daemon to retrieve public key data.
type Option ¶
type Option func(*pubkeyd) error
Option represents a functional option
func WithAthenzURL ¶
WithAthenzURL returns an AthenzURL functional option
func WithETagExpiry ¶
WithETagExpiry returns an ETagExpiry functional option
func WithETagPurgePeriod ¶
WithETagPurgePeriod returns an ETagPurgePeriod functional option
func WithHTTPClient ¶
WithHTTPClient returns a HTTPClient functional option
func WithRefreshPeriod ¶
WithRefreshPeriod returns a RefreshPeriod functional option
func WithRetryDelay ¶
WithRetryDelay returns an RetryDelay functional option
func WithSysAuthDomain ¶
WithSysAuthDomain returns a SysAuthDomain functional option
type SysAuthConfig ¶
type SysAuthConfig struct {
Modified string `json:"modified"`
Name string `json:"name"`
PublicKeys []*PublicKey `json:"publicKeys"`
}
SysAuthConfig represent the system authority config data structure